@@ -12,15 +12,19 @@ from webviz_config import WebvizPluginABC
 
 
 class MorrisPlot(WebvizPluginABC):
-    """### Morris
-
-Renders a visualization of the Morris sampling method.
+    """Renders a visualization of the Morris sampling method.
 The Morris method can be used to screen parameters for how they
 influence model response, both individually and through interaction
 effect with other parameters.
 
-* `csv_file`: Input data
-* `title`: Optional title for the plugin.
+---
+
+* **`csv_file`:** Input data on csv format.
+
+---
+
+[Example of input file](https://github.com/equinor/webviz-subsurface-testdata/blob/master/\
+aggregated_data/morris.csv).
 """
 
     def __init__(self, app, csv_file: Path):
